==> bandcamp-scraper-1.2.8.tgz: package/examples/search.js <==
var bandcamp = require('../lib/index');

var params = {
  query: 'Coeur de pirate',
  page: 1
};

bandcamp.search(params, function(error, searchResults) {
  if (error) {
    console.log(error);
  } else {
    console.log(searchResults);
  }
});

/*
[ { type: 'album',
    name: 'Blonde',
    url: 'http://musique.coeurdepirate.com/album/blonde',
    imageUrl: 'https://f4.bcbits.com/img/a1328452291_7.jpg',
    tags:
     [ 'Québec',
       'montreal',
       'Pop',
       'frenchpop',
       'pianopop',
       'coeurdepirate',
       'Canada',
       'Montréal',
       'amour',
       'grosseboîte',
       'french' ],
    releaseDate: '07 November 2011',
    numTracks: 12,
    numMinutes: 36,
    artist: 'Cœur de pirate' },
  { type: 'artist',
    name: 'Cœur de pirate',
    url: 'http://musique.coeurdepirate.com',
    imageUrl: 'https://f4.bcbits.com/img/0004851352_23.jpg',
    tags: [ 'french', 'Pop', 'pianopop', 'frenchpop' ],
    genre: ' Pop',
    location: 'Montréal, Québec' },
  { type: 'track',
    name: 'Adieu (Lincoln Remix)',
    url: 'https://lincolnplease.bandcamp.com/track/adieu-lincoln-remix',
    imageUrl: 'https://f4.bcbits.com/img/a3583685498_7.jpg',
    tags:
     [ 'House',
       'Funk',
       'HipHop',
       'UnitedStates',
       'groove',
       'dark',
       'future',
       'California',
       'piano',
       'Electronic',
       'SanDiego',
       'bass',
       'Dance' ],
    releaseDate: '02 December 2014',
    album: 'by Cœur de pirate',
    artist: '' },
  { type: 'track',
    name: 'Danse et danse',
    url: 'https://promodaretocare.bandcamp.com/track/danse-et-danse',
    imageUrl: 'https://f4.bcbits.com/img/a2578420227_7.jpg',
    tags: [ 'Pop', 'Montréal', 'piano', 'french', 'GrosseBoîte' ],
    releaseDate: '01 December 2012',
    album: 'from Compilation de Noël 2012',
    artist: 'Coeur de pirate' },
  { type: 'track',
    name: 'Comme des enfants',
    url: 'https://mpourmontreal.bandcamp.com/track/comme-des-enfants',
    imageUrl: 'https://f4.bcbits.com/img/a2364532545_7.jpg',
    tags: [],
    releaseDate: '06 November 2015',
    album: 'from Franco M SiriusXM - Compilation 2006-2015',
    artist: 'Coeur de Pirate' },
  { type: 'track',
    name: 'A la gare viger (cover)',
    url: 'https://lilyfay.bandcamp.com/track/a-la-gare-viger-cover',
    imageUrl: 'https://f4.bcbits.com/img/a1639461967_7.jpg',
    tags: [],
    releaseDate: '17 January 2013',
    album: 'from Live in Livingrooms (home) tour',
    artist: 'Coeur de pirate' },
  { type: 'track',
    name: 'Comme Des Enfants (Le Matos Andy Carmichael Remix)',
    url: 'https://jealousgold.bandcamp.com/track/comme-des-enfants-le-matos-andy-carmichael-remix',
    imageUrl: 'https://f4.bcbits.com/img/a0223773844_7.jpg',
    tags: [ 'hardelectro', 'electrohouse', 'electro' ],
    releaseDate: '30 October 2012',
    album: 'from Golden Days',
    artist: 'Coeur De Pirate' },
  { type: 'track',
    name: 'Comme Des Enfants Cle matis Andy CarMicheal remix',
    url: 'https://djslim1.bandcamp.com/track/comme-des-enfants-cle-matis-andy-carmicheal-remix',
    imageUrl: 'https://f4.bcbits.com/img/a4087143740_7.jpg',
    tags: [],
    releaseDate: '06 June 2013',
    album: 'from Miami COntrol Pt.1',
    artist: 'Coeur De Pirate' },
  { type: 'album',
    name: 'Carry On - Coeur De Pirate',
    url: 'https://malikmq.bandcamp.com/album/carry-on-coeur-de-pirate',
    imageUrl: 'https://f4.bcbits.com/img/a1543646662_7.jpg',
    tags: [ 'England', 'rock', 'London', 'Pop', 'UnitedKingdom' ],
    releaseDate: '29 February 2016',
    numTracks: 1,
    numMinutes: 4,
    artist: 'ma∟ıĸ' },
  { type: 'track',
    name: 'Cœur de pirate - Carry On',
    url: 'https://rawiaalami.bandcamp.com/track/c-ur-de-pirate-carry-on',
    imageUrl: 'https://f4.bcbits.com/img/a3368212248_7.jpg',
    tags: [ 'Palestine', 'Soundtrack' ],
    releaseDate: '19 September 2015',
    album: 'by fansnews1',
    artist: '' },
  { type: 'track',
    name: 'Carry On - Coeur De Pirate',
    url: 'https://malikmq.bandcamp.com/track/carry-on-coeur-de-pirate',
    imageUrl: 'https://f4.bcbits.com/img/a1543646662_7.jpg',
    tags: [],
    releaseDate: '29 February 2016',
    album: 'from Carry On - Coeur De Pirate',
    artist: 'ma∟ıĸ' },
  { type: 'track',
    name: 'Francis (Coeur de Pirate cover)',
    url: 'https://jeneiffel.bandcamp.com/track/francis-coeur-de-pirate-cover',
    imageUrl: 'https://f4.bcbits.com/img/a0532659386_7.jpg',
    tags: [],
    releaseDate: '26 March 2014',
    album: 'from Covers',
    artist: 'Jen Eiffel' },
  { type: 'track',
    name: 'Dans Tes Rêves (avec Coeur De Pirate)',
    url: 'https://commealatelevision.bandcamp.com/track/dans-tes-r-ves-avec-coeur-de-pirate',
    imageUrl: 'https://f4.bcbits.com/img/a1983632539_7.jpg',
    tags: [],
    releaseDate: '15 May 2010',
    album: 'from Comme à la télévision',
    artist: 'Omnikrom' },
  { type: 'track',
    name: 'Coeur De Pirate - Wicked Games Remix',
    url: 'https://globalvortex.bandcamp.com/track/coeur-de-pirate-wicked-games-remix',
    imageUrl: 'https://f4.bcbits.com/img/a0417515816_7.jpg',
    tags: [],
    releaseDate: '02 January 2012',
    album: 'from Red Light Special lp',
    artist: 'OneTwoKno' },
  { type: 'track',
    name: '06. Coeur de Pirate - Adieu (Horny F Remix)',
    url: 'https://hornyf.bandcamp.com/track/06-coeur-de-pirate-adieu-horny-f-remix',
    imageUrl: 'https://f4.bcbits.com/img/a2202690740_7.jpg',
    tags: [],
    releaseDate: '10 February 2013',
    album: 'from Horny F Remixes LP Vol.1',
    artist: 'Horny F' },
  { type: 'track',
    name: 'Peace Sign - Lights + Coeur de Pirate Cover',
    url: 'https://thesteadylungs.bandcamp.com/track/peace-sign-lights-coeur-de-pirate-cover',
    imageUrl: 'https://f4.bcbits.com/img/a1448091967_7.jpg',
    tags: [],
    releaseDate: '23 January 2013',
    album: 'from Demos and Other Nice Stuff',
    artist: 'The Steady Lungs' } ]
*/

==> bandcamp-scraper-1.4.2.tgz: package/examples/search.js <==
const bandcamp = require('../lib/index')

const params = {
  query: 'Coeur de pirate',
  page: 1
}

bandcamp.search(params, function (error, searchResults) {
  if (error) {
    console.log(error)
  } else {
    console.log(searchResults)
  }
})

/*
[ { type: 'album',
    name: 'Blonde',
    url: 'http://musique.coeurdepirate.com/album/blonde',
    imageUrl: 'https://f4.bcbits.com/img/a1328452291_7.jpg',
    tags:
     [ 'Québec',
       'montreal',
       'Pop',
       'frenchpop',
       'pianopop',
       'coeurdepirate',
       'Canada',
       'Montréal',
       'amour',
       'grosseboîte',
       'french' ],
    releaseDate: '07 November 2011',
    numTracks: 12,
    numMinutes: 36,
    artist: 'Cœur de pirate' },
  { type: 'artist',
    name: 'Cœur de pirate',
    url: 'http://musique.coeurdepirate.com',
    imageUrl: 'https://f4.bcbits.com/img/0004851352_23.jpg',
    tags: [ 'french', 'Pop', 'pianopop', 'frenchpop' ],
    genre: ' Pop',
    location: 'Montréal, Québec' },
  { type: 'track',
    name: 'Adieu (Lincoln Remix)',
    url: 'https://lincolnplease.bandcamp.com/track/adieu-lincoln-remix',
    imageUrl: 'https://f4.bcbits.com/img/a3583685498_7.jpg',
    tags:
     [ 'House',
       'Funk',
       'HipHop',
       'UnitedStates',
       'groove',
       'dark',
       'future',
       'California',
       'piano',
       'Electronic',
       'SanDiego',
       'bass',
       'Dance' ],
    releaseDate: '02 December 2014',
    album: 'by Cœur de pirate',
    artist: '' },
  { type: 'track',
    name: 'Danse et danse',
    url: 'https://promodaretocare.bandcamp.com/track/danse-et-danse',
    imageUrl: 'https://f4.bcbits.com/img/a2578420227_7.jpg',
    tags: [ 'Pop', 'Montréal', 'piano', 'french', 'GrosseBoîte' ],
    releaseDate: '01 December 2012',
    album: 'from Compilation de Noël 2012',
    artist: 'Coeur de pirate' },
  { type: 'track',
    name: 'Comme des enfants',
    url: 'https://mpourmontreal.bandcamp.com/track/comme-des-enfants',
    imageUrl: 'https://f4.bcbits.com/img/a2364532545_7.jpg',
    tags: [],
    releaseDate: '06 November 2015',
    album: 'from Franco M SiriusXM - Compilation 2006-2015',
    artist: 'Coeur de Pirate' },
  { type: 'track',
    name: 'A la gare viger (cover)',
    url: 'https://lilyfay.bandcamp.com/track/a-la-gare-viger-cover',
    imageUrl: 'https://f4.bcbits.com/img/a1639461967_7.jpg',
    tags: [],
    releaseDate: '17 January 2013',
    album: 'from Live in Livingrooms (home) tour',
    artist: 'Coeur de pirate' },
  { type: 'track',
    name: 'Comme Des Enfants (Le Matos Andy Carmichael Remix)',
    url: 'https://jealousgold.bandcamp.com/track/comme-des-enfants-le-matos-andy-carmichael-remix',
    imageUrl: 'https://f4.bcbits.com/img/a0223773844_7.jpg',
    tags: [ 'hardelectro', 'electrohouse', 'electro' ],
    releaseDate: '30 October 2012',
    album: 'from Golden Days',
    artist: 'Coeur De Pirate' },
  { type: 'track',
    name: 'Comme Des Enfants Cle matis Andy CarMicheal remix',
    url: 'https://djslim1.bandcamp.com/track/comme-des-enfants-cle-matis-andy-carmicheal-remix',
    imageUrl: 'https://f4.bcbits.com/img/a4087143740_7.jpg',
    tags: [],
    releaseDate: '06 June 2013',
    album: 'from Miami COntrol Pt.1',
    artist: 'Coeur De Pirate' },
  { type: 'album',
    name: 'Carry On - Coeur De Pirate',
    url: 'https://malikmq.bandcamp.com/album/carry-on-coeur-de-pirate',
    imageUrl: 'https://f4.bcbits.com/img/a1543646662_7.jpg',
    tags: [ 'England', 'rock', 'London', 'Pop', 'UnitedKingdom' ],
    releaseDate: '29 February 2016',
    numTracks: 1,
    numMinutes: 4,
    artist: 'ma∟ıĸ' },
  { type: 'track',
    name: 'Cœur de pirate - Carry On',
    url: 'https://rawiaalami.bandcamp.com/track/c-ur-de-pirate-carry-on',
    imageUrl: 'https://f4.bcbits.com/img/a3368212248_7.jpg',
    tags: [ 'Palestine', 'Soundtrack' ],
    releaseDate: '19 September 2015',
    album: 'by fansnews1',
    artist: '' },
  { type: 'track',
    name: 'Carry On - Coeur De Pirate',
    url: 'https://malikmq.bandcamp.com/track/carry-on-coeur-de-pirate',
    imageUrl: 'https://f4.bcbits.com/img/a1543646662_7.jpg',
    tags: [],
    releaseDate: '29 February 2016',
    album: 'from Carry On - Coeur De Pirate',
    artist: 'ma∟ıĸ' },
  { type: 'track',
    name: 'Francis (Coeur de Pirate cover)',
    url: 'https://jeneiffel.bandcamp.com/track/francis-coeur-de-pirate-cover',
    imageUrl: 'https://f4.bcbits.com/img/a0532659386_7.jpg',
    tags: [],
    releaseDate: '26 March 2014',
    album: 'from Covers',
    artist: 'Jen Eiffel' },
  { type: 'track',
    name: 'Dans Tes Rêves (avec Coeur De Pirate)',
    url: 'https://commealatelevision.bandcamp.com/track/dans-tes-r-ves-avec-coeur-de-pirate',
    imageUrl: 'https://f4.bcbits.com/img/a1983632539_7.jpg',
    tags: [],
    releaseDate: '15 May 2010',
    album: 'from Comme à la télévision',
    artist: 'Omnikrom' },
  { type: 'track',
    name: 'Coeur De Pirate - Wicked Games Remix',
    url: 'https://globalvortex.bandcamp.com/track/coeur-de-pirate-wicked-games-remix',
    imageUrl: 'https://f4.bcbits.com/img/a0417515816_7.jpg',
    tags: [],
    releaseDate: '02 January 2012',
    album: 'from Red Light Special lp',
    artist: 'OneTwoKno' },
  { type: 'track',
    name: '06. Coeur de Pirate - Adieu (Horny F Remix)',
    url: 'https://hornyf.bandcamp.com/track/06-coeur-de-pirate-adieu-horny-f-remix',
    imageUrl: 'https://f4.bcbits.com/img/a2202690740_7.jpg',
    tags: [],
    releaseDate: '10 February 2013',
    album: 'from Horny F Remixes LP Vol.1',
    artist: 'Horny F' },
  { type: 'track',
    name: 'Peace Sign - Lights + Coeur de Pirate Cover',
    url: 'https://thesteadylungs.bandcamp.com/track/peace-sign-lights-coeur-de-pirate-cover',
    imageUrl: 'https://f4.bcbits.com/img/a1448091967_7.jpg',
    tags: [],
    releaseDate: '23 January 2013',
    album: 'from Demos and Other Nice Stuff',
    artist: 'The Steady Lungs' } ]
*/
